===========================
 Invenio-Migrator v1.0.0a3
===========================

Invenio-Migrator v1.0.0a3 was released on May 4, 2016.

About
-----

Utilities for migrating past Invenio versions to Invenio 3.0.

*This is an experimental developer preview release.*

What's new
----------

- Initial public release.

Installation
------------

   $ pip install invenio-migrator==1.0.0a3

Documentation
-------------

   http://pythonhosted.org/invenio-migrator/

Happy hacking and thanks for flying Invenio-Migrator.

| Invenio Development Team
|   Email: info@invenio-software.org
|   IRC: #invenio on irc.freenode.net
|   Twitter: http://twitter.com/inveniosoftware
|   GitHub: https://github.com/inveniosoftware/invenio-migrator
|   URL: http://invenio-software.org
